@@ -33,19 +33,17 @@ SOFTWARE.
 int uart_setup(const char *dt)
 {
     if (load_device_tree(dt)) {
-        fprintf(stderr, "return 1 uart_setup");
         return 1;
     }
 
-fprintf(stderr, "return 1 uart_setup");
     return 0;
 }
 
 void uart_cleanup(void)
 {
-    unload_device_tree("BB-UART1");
-    unload_device_tree("BB-UART2");
-    unload_device_tree("BB-UART3");
-    unload_device_tree("BB-UART4");
-    unload_device_tree("BB-UART5");
+    unload_device_tree("ADAFRUIT-UART1");
+    unload_device_tree("ADAFRUIT-UART2");
+    unload_device_tree("ADAFRUIT-UART3");
+    unload_device_tree("ADAFRUIT-UART4");
+    unload_device_tree("ADAFRUIT-UART5");
 }
