@@ -154,11 +154,11 @@ typedef struct uart_t {
 } uart_t;
 
 uart_t uart_table[] = {
-  { "UART1", "/dev/ttyO1", "BB-UART1", "P9_26", "P9_24"},
-  { "UART2", "/dev/ttyO2", "BB-UART2", "P9_22", "P9_21"},
-  { "UART3", "/dev/ttyO3", "BB-UART3", "P9_42", ""},
-  { "UART4", "/dev/ttyO4", "BB-UART4", "P9_11", "P9_13"},
-  { "UART5", "/dev/ttyO5", "BB-UART5", "P8_38", "P8_37"},
+  { "UART1", "/dev/ttyO1", "ADAFRUIT-UART1", "P9_26", "P9_24"},
+  { "UART2", "/dev/ttyO2", "ADAFRUIT-UART2", "P9_22", "P9_21"},
+  { "UART3", "/dev/ttyO3", "ADAFRUIT-UART3", "P9_42", ""},
+  { "UART4", "/dev/ttyO4", "ADAFRUIT-UART4", "P9_11", "P9_13"},
+  { "UART5", "/dev/ttyO5", "ADAFRUIT-UART5", "P8_38", "P8_37"},
   { NULL, NULL, 0 }
 };
 
