@@ -14,4 +14,9 @@ class TestGPIOInput:
         #value read from the file will have a \n new line
         value = open('/sys/class/gpio/gpio68/value').read()
         assert int(value) == input_value
-        GPIO.cleanup()
\ No newline at end of file
+        GPIO.cleanup()
+
+    def test_direction_readback(self):
+        GPIO.setup("P8_10", GPIO.IN)
+        direction = GPIO.gpio_function("P8_10")
+        assert direction == GPIO.IN
